@@ -13,13 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import struct_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.type import money_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.recommender.v1beta1",
@@ -113,26 +111,66 @@ class Recommendation(proto.Message):
                 projects/[PROJECT_NUMBER]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID]/insights/[INSIGHT_ID]
         """
 
-        insight = proto.Field(proto.STRING, number=1,)
+        insight = proto.Field(
+            proto.STRING,
+            number=1,
+        )
 
-    name = proto.Field(proto.STRING, number=1,)
-    description = proto.Field(proto.STRING, number=2,)
-    recommender_subtype = proto.Field(proto.STRING, number=12,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    recommender_subtype = proto.Field(
+        proto.STRING,
+        number=12,
+    )
     last_refresh_time = proto.Field(
-        proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    primary_impact = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="Impact",
+    )
+    additional_impact = proto.RepeatedField(
+        proto.MESSAGE,
+        number=6,
+        message="Impact",
+    )
+    priority = proto.Field(
+        proto.ENUM,
+        number=17,
+        enum=Priority,
+    )
+    content = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message="RecommendationContent",
     )
-    primary_impact = proto.Field(proto.MESSAGE, number=5, message="Impact",)
-    additional_impact = proto.RepeatedField(proto.MESSAGE, number=6, message="Impact",)
-    priority = proto.Field(proto.ENUM, number=17, enum=Priority,)
-    content = proto.Field(proto.MESSAGE, number=7, message="RecommendationContent",)
     state_info = proto.Field(
-        proto.MESSAGE, number=10, message="RecommendationStateInfo",
+        proto.MESSAGE,
+        number=10,
+        message="RecommendationStateInfo",
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=11,
     )
-    etag = proto.Field(proto.STRING, number=11,)
     associated_insights = proto.RepeatedField(
-        proto.MESSAGE, number=14, message=InsightReference,
+        proto.MESSAGE,
+        number=14,
+        message=InsightReference,
+    )
+    xor_group_id = proto.Field(
+        proto.STRING,
+        number=18,
     )
-    xor_group_id = proto.Field(proto.STRING, number=18,)
 
 
 class RecommendationContent(proto.Message):
@@ -151,9 +189,15 @@ class RecommendationContent(proto.Message):
     """
 
     operation_groups = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="OperationGroup",
+        proto.MESSAGE,
+        number=2,
+        message="OperationGroup",
+    )
+    overview = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=struct_pb2.Struct,
     )
-    overview = proto.Field(proto.MESSAGE, number=3, message=struct_pb2.Struct,)
 
 
 class OperationGroup(proto.Message):
@@ -167,7 +211,11 @@ class OperationGroup(proto.Message):
             order they appear.
     """
 
-    operations = proto.RepeatedField(proto.MESSAGE, number=1, message="Operation",)
+    operations = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Operation",
+    )
 
 
 class Operation(proto.Message):
@@ -232,7 +280,7 @@ class Operation(proto.Message):
             for 'test' operation.
 
             This field is a member of `oneof`_ ``path_value``.
-        path_filters (Sequence[google.cloud.recommender_v1beta1.types.Operation.PathFiltersEntry]):
+        path_filters (Mapping[str, google.protobuf.struct_pb2.Value]):
             Set of filters to apply if ``path`` refers to array elements
             or nested array elements in order to narrow down to a single
             unique element that is being tested/modified. This is
@@ -268,7 +316,7 @@ class Operation(proto.Message):
 
             When both path_filters and path_value_matchers are set, an
             implicit AND must be performed.
-        path_value_matchers (Sequence[google.cloud.recommender_v1beta1.types.Operation.PathValueMatchersEntry]):
+        path_value_matchers (Mapping[str, google.cloud.recommender_v1beta1.types.ValueMatcher]):
             Similar to path_filters, this contains set of filters to
             apply if ``path`` field refers to array elements. This is
             meant to support value matching beyond exact match. To
@@ -277,23 +325,53 @@ class Operation(proto.Message):
             AND must be performed.
     """
 
-    action = proto.Field(proto.STRING, number=1,)
-    resource_type = proto.Field(proto.STRING, number=2,)
-    resource = proto.Field(proto.STRING, number=3,)
-    path = proto.Field(proto.STRING, number=4,)
-    source_resource = proto.Field(proto.STRING, number=5,)
-    source_path = proto.Field(proto.STRING, number=6,)
+    action = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    resource_type = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    resource = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    path = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    source_resource = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    source_path = proto.Field(
+        proto.STRING,
+        number=6,
+    )
     value = proto.Field(
-        proto.MESSAGE, number=7, oneof="path_value", message=struct_pb2.Value,
+        proto.MESSAGE,
+        number=7,
+        oneof="path_value",
+        message=struct_pb2.Value,
     )
     value_matcher = proto.Field(
-        proto.MESSAGE, number=10, oneof="path_value", message="ValueMatcher",
+        proto.MESSAGE,
+        number=10,
+        oneof="path_value",
+        message="ValueMatcher",
     )
     path_filters = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=8, message=struct_pb2.Value,
+        proto.STRING,
+        proto.MESSAGE,
+        number=8,
+        message=struct_pb2.Value,
     )
     path_value_matchers = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=11, message="ValueMatcher",
+        proto.STRING,
+        proto.MESSAGE,
+        number=11,
+        message="ValueMatcher",
     )
 
 
@@ -315,7 +393,11 @@ class ValueMatcher(proto.Message):
             This field is a member of `oneof`_ ``match_variant``.
     """
 
-    matches_pattern = proto.Field(proto.STRING, number=1, oneof="match_variant",)
+    matches_pattern = proto.Field(
+        proto.STRING,
+        number=1,
+        oneof="match_variant",
+    )
 
 
 class CostProjection(proto.Message):
@@ -336,8 +418,16 @@ class CostProjection(proto.Message):
             Duration for which this cost applies.
     """
 
-    cost = proto.Field(proto.MESSAGE, number=1, message=money_pb2.Money,)
-    duration = proto.Field(proto.MESSAGE, number=2, message=duration_pb2.Duration,)
+    cost = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=money_pb2.Money,
+    )
+    duration = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=duration_pb2.Duration,
+    )
 
 
 class SecurityProjection(proto.Message):
@@ -349,7 +439,11 @@ class SecurityProjection(proto.Message):
             define details specific to security impact.
     """
 
-    details = proto.Field(proto.MESSAGE, number=2, message=struct_pb2.Struct,)
+    details = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=struct_pb2.Struct,
+    )
 
 
 class SustainabilityProjection(proto.Message):
@@ -366,8 +460,15 @@ class SustainabilityProjection(proto.Message):
             applies.
     """
 
-    kg_c_o2e = proto.Field(proto.DOUBLE, number=1,)
-    duration = proto.Field(proto.MESSAGE, number=2, message=duration_pb2.Duration,)
+    kg_c_o2e = proto.Field(
+        proto.DOUBLE,
+        number=1,
+    )
+    duration = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=duration_pb2.Duration,
+    )
 
 
 class Impact(proto.Message):
@@ -407,12 +508,22 @@ class Impact(proto.Message):
         MANAGEABILITY = 4
         SUSTAINABILITY = 5
 
-    category = proto.Field(proto.ENUM, number=1, enum=Category,)
+    category = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=Category,
+    )
     cost_projection = proto.Field(
-        proto.MESSAGE, number=100, oneof="projection", message="CostProjection",
+        proto.MESSAGE,
+        number=100,
+        oneof="projection",
+        message="CostProjection",
     )
     security_projection = proto.Field(
-        proto.MESSAGE, number=101, oneof="projection", message="SecurityProjection",
+        proto.MESSAGE,
+        number=101,
+        oneof="projection",
+        message="SecurityProjection",
     )
     sustainability_projection = proto.Field(
         proto.MESSAGE,
@@ -429,7 +540,7 @@ class RecommendationStateInfo(proto.Message):
         state (google.cloud.recommender_v1beta1.types.RecommendationStateInfo.State):
             The state of the recommendation, Eg ACTIVE,
             SUCCEEDED, FAILED.
-        state_metadata (Sequence[google.cloud.recommender_v1beta1.types.RecommendationStateInfo.StateMetadataEntry]):
+        state_metadata (Mapping[str, str]):
             A map of metadata for the state, provided by
             user or automations systems.
     """
@@ -443,8 +554,16 @@ class RecommendationStateInfo(proto.Message):
         FAILED = 4
         DISMISSED = 5
 
-    state = proto.Field(proto.ENUM, number=1, enum=State,)
-    state_metadata = proto.MapField(proto.STRING, proto.STRING, number=2,)
+    state = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=State,
+    )
+    state_metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
