@@ -13,15 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import struct_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.recommender.v1beta1",
-    manifest={"RecommenderConfig", "RecommenderGenerationConfig",},
+    manifest={
+        "RecommenderConfig",
+        "RecommenderGenerationConfig",
+    },
 )
 
 
@@ -46,7 +47,7 @@ class RecommenderConfig(proto.Message):
             the config. A new revision is committed whenever
             the config is changed in any way. The format is
             an 8-character hexadecimal string.
-        annotations (Sequence[google.cloud.recommender_v1beta1.types.RecommenderConfig.AnnotationsEntry]):
+        annotations (Mapping[str, str]):
             Allows clients to store small amounts of arbitrary data.
             Annotations must follow the Kubernetes syntax. The total
             size of all keys and values combined is limited to 256k. Key
@@ -61,15 +62,37 @@ class RecommenderConfig(proto.Message):
             interfaces.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     recommender_generation_config = proto.Field(
-        proto.MESSAGE, number=2, message="RecommenderGenerationConfig",
+        proto.MESSAGE,
+        number=2,
+        message="RecommenderGenerationConfig",
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    revision_id = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    annotations = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=6,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=7,
     )
-    etag = proto.Field(proto.STRING, number=3,)
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    revision_id = proto.Field(proto.STRING, number=5,)
-    annotations = proto.MapField(proto.STRING, proto.STRING, number=6,)
-    display_name = proto.Field(proto.STRING, number=7,)
 
 
 class RecommenderGenerationConfig(proto.Message):
@@ -84,7 +107,11 @@ class RecommenderGenerationConfig(proto.Message):
             be used by or are applied to all subtypes.
     """
 
-    params = proto.Field(proto.MESSAGE, number=1, message=struct_pb2.Struct,)
+    params = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=struct_pb2.Struct,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
